use crate::Result;
use async_trait::async_trait;
use clickhouse::Client;
use futures::Future;

#[async_trait]
pub trait Migratable {
    async fn run(&self, db: &Client) -> Result<()>;
}

#[async_trait]
impl Migratable for &str {
    async fn run(&self, db: &Client) -> Result<()> {
        db.query(self).execute().await?;
        Ok(())
    }
}

#[async_trait]
impl<F, O> Migratable for F
where
    F: Fn(&Client) -> O + Sync + Send,
    O: Future<Output = Result<()>> + Send,
{
    async fn run(&self, db: &Client) -> Result<()> {
        self(db).await
    }
}
